<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Banks;
use Illuminate\Http\Request;

class BanksController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = Banks::orderByDesc( 'id')->get();
        return view('admin.banks.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.banks.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'bank_name_ar' => 'required',
            'bank_name_en' => 'required',
            'image' => 'required|image',
            'account_number' => 'required',
            'iban_number' => 'required',
            'account_name' => 'required',
            'status' => 'required|in:active,not_active',
        ]);
        $bank = new Banks();
        $bank['bank_name->ar'] = $request['bank_name_ar'];
        $bank['bank_name->en'] = $request['bank_name_en'];
        $bank->setImageAttribute();
        $bank['account_number'] = $request['account_number'];
        $bank['iban_number'] = $request['iban_number'];
        $bank['account_name'] = $request['account_name'];
        $bank['status'] = $request['status'];
        $bank->save();
        return redirect()->route('banks.index')->with('message', 'تم اضافه البنك بنجاح');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = Banks::find($id);
        return view('admin.banks.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'bank_name_ar' => 'required',
            'bank_name_en' => 'required',
            'image' => 'image',
            'account_number' => 'required',
            'iban_number' => 'required',
            'account_name' => 'required',
            'status' => 'required|in:active,not_active',
        ]);
        $bank = Banks::find($id);
        $bank['bank_name->ar'] = $request['bank_name_ar'];
        $bank['bank_name->en'] = $request['bank_name_en'];
        if ($request->hasFile('image')) $bank->setImageAttribute();
        $bank['account_number'] = $request['account_number'];
        $bank['iban_number'] = $request['iban_number'];
        $bank['account_name'] = $request['account_name'];
        $bank['status'] = $request['status'];
        $bank->update();
        return redirect()->route('banks.index')->with('message', 'تم تعديل البنك بنجاح');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $row = Banks::find($id);
        $row->deleteImage();
        Banks::destroy($id);
        return redirect()->back()->with('message','تم الحذف بنجاح');
    }
}
