<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Banner;
use Illuminate\Http\Request;

class BannersController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = Banner::orderByDesc('id')->get();
        return  view('admin.banners.index',compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return  view('admin.banners.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request,[
            'image'=>'required|image'
        ]);
        Banner::create($request->all());
        return  redirect()->route('banners.index')->with('message','تم الإنشاء بنجاح');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = Banner::find($id);
        return  view('admin.banners.edit',compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request,[
            'image'=>'image'
        ]);
        $row = Banner::find($id);
        if ($request->hasFile('image')){
            $row->setImageAttribute();
        }
        $row->update();
        return  redirect()->route('banners.index')->with('message','تم التعديل بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $row = Banner::find($id);
        $row->deleteImage();
        Banner::destroy($id);
        return redirect()->back()->with('message','تم الحذف بنجاح');
    }
    public function show_home($id){
        Banner::where('id',$id)->update([
            'show_home'=>'true'
        ]);
        return redirect()->back()->with('message','تم إظهار العنصر في الرئيسية');
    }

    public function hide_home($id)
    {
        Banner::where('id', $id)->update([
            'show_home' => 'false'
        ]);
        return redirect()->back()->with('message', 'تم إخفاء العنصر من الرئيسية');
    }
}
