<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\CityResource;
use App\Http\Resources\CountryCodesResource;
use App\Http\Resources\PagesResource;
use App\Http\Resources\ProductsResource;
use App\Models\BannedService;
use App\Models\CarSubscription;
use App\Models\Category;
use App\Models\City;
use App\Models\ContactDesc;
use App\Models\CountryCodes;
use App\Models\DiscountRating;
use App\Models\Licence;
use App\Models\Product;
use App\Models\Setting;
use App\Models\UsageTerm;
use Illuminate\Http\Request;
use function Symfony\Component\VarDumper\Dumper\esc;
use JWTAuth;

class DataController extends Controller
{
    public function country_codes()
    {

        $rows = CountryCodes::all();
        $data = CountryCodesResource::collection($rows);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
    }

    public function pages(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'flag' => 'required|in:contact_desc,usage_terms,discount_rating,car_subscriptions,banned_services'
        ]);
        $flag = $request['flag'];
        if ($validator->passes()) {

            if ($flag == 'contact_desc') {
                $rows = ContactDesc::orderByDesc('id')->get();
            } elseif ($flag == 'usage_terms') {
                $rows = UsageTerm::orderByDesc('id')->get();

            } elseif ($flag == 'discount_rating') {
                $rows = DiscountRating::orderByDesc('id')->get();

            } elseif ($flag == 'car_subscriptions') {
                $rows = CarSubscription::orderByDesc('id')->get();

            } elseif ($flag == 'banned_services') {
                $rows = BannedService::orderByDesc('id')->get();
            }
            $data = PagesResource::collection($rows);
            return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }


    }

    public function cities($id = null)
    {
        if ($id) {
            $rows = City::whereParentId($id)->get();
        } else {
            $rows = City::whereNull('parent_id')->get();
        }
        $data = CityResource::collection($rows);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
    }

    public function calc_commission(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'amount' => 'required',
        ]);
        if ($validator->passes()) {
            $setting = Setting::first();

            if ($setting && $setting->commission) {
                $data = (integer)$request['amount'] * $setting->commission / 100;
            } else {
                $data = $request['amount'] * 1 / 100;
            }
            return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }
    }

    public function licence(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'name' => 'required',
            'number' => 'required',
            'image' => 'required|image',
            'details' => 'required',
            'type' => 'required|in:commercial_record,professional_record,professional_record,municipal_registry,other'
        ]);
        if ($validator->passes()) {
            Licence::create($request->all());
            return response()->json(['value' => true, 'data' => \Lang::get('data.licence_submitted'), 'code' => 200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }
    }

    public function settings(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $setting = Setting::first();
        $data['site_name'] = ($setting && $setting->site_name) ? $setting->site_name[$lang] : '';
        $data['address'] = ($setting && $setting->address) ? $setting->address[$lang] : '';
        $data['discount_system'] = ($setting && $setting->discount_system) ? $setting->discount_system[$lang] : '';
        $data['commission_system'] = ($setting && $setting->commission_system) ? $setting->commission_system[$lang] : '';
        $data['site_logo'] = ($setting && $setting->site_logo) ? $setting->site_logo : '';
        $data['ios_link'] = ($setting && $setting->ios_link) ? $setting->ios_link : '';
        $data['android_link'] = ($setting && $setting->android_link) ? $setting->android_link : '';
        $data['commission'] = ($setting && $setting->commision) ? $setting->commission : '';
        $data['commercial_record'] = ($setting && $setting->commercial_record) ? $setting->commercial_record : '';
        $data['tax_number'] = ($setting && $setting->tax_number) ? $setting->tax_number : '';
        $data['year_subscription'] = ($setting && $setting->year_subscription) ? $setting->year_subscription : '';
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
    }

    public function home($id, Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if ($id != 0) {
            $parent = Category::find($id); // grand category
            $parent_categories = $parent->categories->pluck('id');
            $childrens = Category::whereIn('parent_id', $parent->categories->pluck('id'))->pluck('id');
            $all_categories = $childrens->merge($parent_categories);
            $all_all_categories = $all_categories->merge($id);
            $products = Product::whereIn('category_id', $all_all_categories)->whereStatus('active')->orderByDesc('id')->paginate(10);
        } else {
            $products = Product::whereStatus('active')->orderByDesc('id')->paginate(10);
        }
        return ProductsResource::collection($products)->additional(['value' => true, 'code' => 200]);
    }

    public function advanced_search(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if ($request->header('Authorization')) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
            }
        }
        $validator = \Validator::make($request->all(), [
            'grand_id' => 'required',
            'parent_id' => 'required',
            'children_id' => 'required'
        ]);
        if ($validator->passes()) {
            $grand_id = $request['grand_id'];
            $parent_id = $request['parent_id'];
            $children_id = $request['children_id'];
            $lat = $request['lat'];
            $lng = $request['lng'];
            $max_distance = 30;
            $lat_small = $lat - ($max_distance * 0.018);
            $lat_large = $lat + ($max_distance * 0.018);
            $lng_small = $lng - ($max_distance * 0.018);
            $lng_large = $lng + ($max_distance * 0.018);


            if ($grand_id == 0 && $parent_id == 0 && $children_id == 0) {


                if ($request['has_image']) {
                    $products = Product::where('status', 'active')->whereHas('images')->orderByDesc('id')->get();

                } elseif ($request['city_id']) {
                    $products = Product::where('status', 'active')->where('city_id', $request['city_id'])->orderByDesc('id')->get();

                } elseif ($request['city_id'] && $request['has_image']) {
                    $products = Product::where('status', 'active')->where('city_id', $request['city_id'])->whereHas('images')->orderByDesc('id')->get();

                } elseif ($request['lat']) {
                    $products = Product::where('status', 'active')->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->orderByDesc('id')->get();

                } elseif ($request['lat'] && $request['has_image']) {
                    $products = Product::where('status', 'active')->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->whereHas('images')->orderByDesc('id')->get();

                } elseif ($request['lat'] && $request['city_id']) {
                    $products = Product::where('status', 'active')->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->where('city_id', $request['city_id'])->orderByDesc('id')->get();

                } elseif ($request['lat'] && $request['city_id'] && $request['has_image']) {
                    $products = Product::where('status', 'active')->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->where('city_id', $request['city_id'])->whereHas('images')->orderByDesc('id')->get();

                } else {
                    $products = Product::where('status', 'active')->orderByDesc('id')->get();

                }
            } elseif ($grand_id != 0 && $parent_id == 0 && $children_id == 0) {
                $parent = Category::find($grand_id);
                $childrens = Category::whereIn('parent_id', $parent->categories->pluck('id'))->pluck('id');
                $parent_categories = $parent->categories->pluck('id');
                $all_categories = $childrens->merge($parent_categories);


                if ($request['city_id']) {
                    $products = Product::whereIn('category_id', $all_categories)->whereStatus('active')->where('city_id', $request['city_id'])->orderByDesc('id')->paginate(10);

                } elseif ($request['lat']) {
                    $products = Product::whereIn('category_id', $all_categories)->whereStatus('active')->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->orderByDesc('id')->paginate(10);

                } elseif ($request['lat'] && $request['city_id']) {
                    $products = Product::whereIn('category_id', $all_categories)->whereStatus('active')->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->where('city_id', $request['city_id'])->orderByDesc('id')->paginate(10);

                } else {
                    $products = Product::whereIn('category_id', $all_categories)->whereStatus('active')->orderByDesc('id')->paginate(10);

                }


            } elseif ($grand_id != 0 && $parent_id != 0 && $children_id == 0) {

                $categories_children = Category::where(['status' => 'active', 'parent_id' => $parent_id])->pluck('id')->toArray(); // category child

                array_push($categories_children, (integer)$parent_id);

                if ($request['city_id']) {
                    $products = Product::whereStatus('active')->whereIn('category_id', $categories_children)->where('city_id', $request['city_id'])->orderByDesc('id')->paginate(10);

                } elseif ($request['lat']) {
                    $products = Product::whereStatus('active')->whereIn('category_id', $categories_children)->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->orderByDesc('id')->paginate(10);

                } elseif ($request['lat'] && $request['city_id']) {
                    $products = Product::whereStatus('active')->whereIn('category_id', $categories_children)->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->where('city_id', $request['city_id'])->orderByDesc('id')->paginate(10);

                } else {
                    $products = Product::whereStatus('active')->whereIn('category_id', $categories_children)->orderByDesc('id')->paginate(10);

                }


            } elseif ($grand_id != 0 && $parent_id != 0 && $children_id != 0) {

                $category = Category::find($children_id)->value('car_option');
                if ($category == 'true' && $request['year']) {
                    $products = Product::where(['status' => 'active', 'category_id' => $children_id])->where('year', $request['year'])->orderByDesc('id')->paginate(10);

                } elseif ($request['city_id']) {
                    $products = Product::where(['status' => 'active', 'category_id' => $children_id])->where('city_id', $request['city_id'])->orderByDesc('id')->paginate(10);
                } elseif ($request['city_id'] && $request['year'] && $category == 'true') {
                    $products = Product::where(['status' => 'active', 'category_id' => $children_id])->where('city_id', $request['city_id'])->where('year', $request['year'])->orderByDesc('id')->paginate(10);
                } elseif ($request['lat']) {
                    $products = Product::where(['status' => 'active', 'category_id' => $children_id])->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->orderByDesc('id')->paginate(10);
                } elseif ($request['lat'] && $request['city_id']) {
                    $products = Product::where(['status' => 'active', 'category_id' => $children_id])->where('city_id', $request['city_id'])->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->orderByDesc('id')->paginate(10);
                } elseif ($request['lat'] && $request['year']) {
                    $products = Product::where(['status' => 'active', 'category_id' => $children_id])->whereYear($request['year'])->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->orderByDesc('id')->paginate(10);
                } elseif ($request['lat'] && $request['year'] && $request['city_id']) {
                    $products = Product::where(['status' => 'active', 'category_id' => $children_id])->whereHas('images')->whereCityId($request['city_id'])->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->orderByDesc('id')->paginate(10);
                } else {
                    $products = Product::where(['status' => 'active', 'category_id' => $children_id])->orderByDesc('id')->paginate(10);

                }

            }

            return ProductsResource::collection($products)->additional(['value' => true, 'code' => 200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }


    }

}
