<?php

namespace App\Http\Controllers\Web;

use App\Http\Controllers\Controller;
use App\Http\Resources\BlackListUsersResource;
use App\Models\Banks;
use App\Models\Block;
use App\Models\Category;
use App\Models\City;
use App\Models\Product;
use App\Models\Setting;
use App\Models\Transfer;
use Illuminate\Http\Request;

class DataController extends Controller
{

    public function calc_commission(Request $request)
    {
        $banks = Banks::whereStatus('active')->get();
        $setting = Setting::first();
        return view('web.data.calc-commission', compact('banks', 'setting'));
    }

    public function commission()
    {
        return view('web.data.commission');
    }

    public function payment_commission(Request $request)
    {

        $this->validate($request, [
            'amount' => 'required',
            'transfer_date' => 'required',
            'full_name' => 'required',
            'mobile' => 'required|exists:users,mobile',
            'product_number' => 'required|exists:products,code',
            'bank_id' => 'required|exists:banks,id',
        ]);

        $row = new Transfer();
        $row->amount = $request->amount;
        $row->transfer_date = $request->transfer_date;
        $row->full_name = $request->full_name;
        $row->mobile = $request->mobile;
        $row->product_number = $request->product_number;
        $row->bank_id = $request->bank_id;
        $row->user_id = \Auth::user()->id;
        $row->save();
        return redirect()->back()->with('message', \Lang::get('data.payment_commission'));
    }

    public function calc(Request $request)
    {
        if ($request->amount) {
            $amount = $request->amount * Setting::first()->value('commission');
            $data = $amount / 100;
            return response()->json(['status' => 1, 'data' => round($data)]);
        }
    }

    public function discount()
    {
        return view('web.data.discount');
    }

    public function search(Request $request)
    {
        $this->validate($request, [
            'search' => 'required',
        ]);
        $rows = Product::where('title', 'like', "%$request->search%")->where('status', 'active')->paginate(12);
        $req = $request->search;
        return view('web.data.search', compact('rows', 'req'));
    }

    public function key_words($category_id)
    {
        $category = Category::find($category_id);
        $parent_category = Category::find($category->parent_id);

        if ($parent_category) {
            $categories = Category::whereParentId($parent_category->id)->get();
        } else {
            $categories = Category::whereParentId($category->id)->get();
        }
        return $categories;
    }

    public function categories($id)
    {
        $category = Category::find($id);


        if ($id) {
            if ($category->parent_id == null) {
                $categories = $category->categories->pluck('id');
                $all_categories = $categories->merge($id);

                foreach ($category->categories as $small_category) {
                    $all_categories->merge($small_category->id);
                }

                $rows = Product::whereStatus('active')->whereIn('category_id', $all_categories)->orderByDesc('id')->paginate(12);
                $req = '';
                $key_words = $this->key_words($id);
                return view('web.data.category', compact('rows', 'req', 'category', 'key_words'));
            } else {
                $categories = $category->categories->pluck('id');
                $all_categories = $categories->merge($id);
                $rows = Product::whereStatus('active')->whereIn('category_id', $all_categories)->orderByDesc('id')->paginate(12);
                $req = '';
                $key_words = $this->key_words($id);

                return view('web.data.category', compact('rows', 'req', 'category', 'key_words'));
            }

        } else {
            return redirect()->route('home');
        }
    }

    public function filter_home(Request $request)
    {
        $this->validate($request, [
            'grand_id' => 'required|numeric|exists:categories,id'
        ], [
            'grand_id.required' => \Lang::get('data.select_category'),
            'grand_id.numeric' => \Lang::get('data.select_category'),
            'grand_id.exists' => \Lang::get('data.select_category'),
        ]);


        $grand_id = $request['grand_id'];
        $parent_id = $request['parent_id'];
        $children_id = $request['child_id'];

        if ($grand_id != null && $parent_id == null && $children_id == null) {
            $grand = Category::find($grand_id);

            $parents = Category::whereParentId($grand_id)->pluck('id');

            $categories_id = $parents->merge($grand->id);
            $childrens = Category::whereIn('parent_id', $parents)->pluck('id');
            $all_categories = $categories_id->merge($childrens);


            $rows = Product::whereIn('category_id', $all_categories)->whereStatus('active')->orderByDesc('id')->paginate(12);


        } elseif ($grand_id != null && $parent_id != null && $children_id == null) {

            $categories_children = Category::where(['status' => 'active', 'parent_id' => $parent_id])->pluck('id')->toArray(); // category child

            array_push($categories_children, (integer)$parent_id);


            $rows = Product::whereStatus('active')->whereIn('category_id', $categories_children)->orderByDesc('id')->paginate(12);


        } elseif ($grand_id != null && $parent_id != null && $children_id != null) {

            $category = Category::find($children_id)->value('car_option');


            $rows = Product::where(['status' => 'active', 'category_id' => $children_id])->orderByDesc('id')->paginate(10);

        }
        $req = '';
        return view('web.data.search', compact('rows', 'req'));


    }


    public function search_city_ajax(Request $request)
    {

        $cites = City::where('parent_id', $request->city_id)->pluck('id');
        $cites->merge($request->city_id);

        if ($request->category_id) {
            $category = Category::find($request['category_id']);
            $children = Category::where('parent_id', $category->id)->pluck('id');
            $all_categories = $children->merge($category);
            $rows = Product::where('category_id', $request['category_id'])->where('status', 'active')->where('city_id', $request->city_id)->paginate(12);

        } else {
            $rows = Product::where('title', 'like', "%$request->search%")->where('status', 'active')->whereIn('city_id', $cites)->paginate(12);

        }


        $view = view('web.data.data_search', compact('rows'))->render();;
        return response()->json(['html' => $view]);
    }

    public function get_tap_products(Request $request)
    {
        \Session::put('tap_category_id', $request->category_id);

        if ($request->category_id != null) {
            $category = Category::find($request['category_id']); // 15 grand
            $parents = Category::where('parent_id', $category->id)->pluck('id');
            $all_categories = $parents->merge($category->id); // 15 , 16
            $children = Category::whereIn('parent_id', $parents)->pluck('id');
            $chlidren_categories = $all_categories->merge($children);

            $rows = Product::whereIn('category_id', $chlidren_categories)->where('status', 'active')->paginate(12);
            $category_name = $category->name[\App::getLocale()];

        } else {
            $rows = Product::paginate(12);
            $category_name = \Lang::get('data.all');

        }


        $view = view('web.data.data_search', compact('rows'))->render();;
        return response()->json(['html' => $view, 'category_name' => $category_name]);
    }

    public function tap_products_city(Request $request)
    {
        \Session::put('tap_city_id', $request->city_id);
        $category_id = \Session::get('tap_category_id');
        if ($category_id != null) {
            $category = Category::find($category_id); // 15 grand
            $parents = Category::where('parent_id', $category->id)->pluck('id');
            $all_categories = $parents->merge($category->id); // 15 , 16
            $children = Category::whereIn('parent_id', $parents)->pluck('id');
            $chlidren_categories = $all_categories->merge($children);


            $city_grand = City::find($request->city_id);
            $cities_parents = City::whereParentId($city_grand->id)->pluck('id');
            $all_cities = $cities_parents->merge($city_grand->id);
            $cities_childrens = City::whereIn('parent_id', $cities_parents)->pluck('id');
            $cities = $all_cities->merge($cities_childrens);


            $rows = Product::whereIn('category_id', $chlidren_categories)->whereIn('city_id', $cities)->where('status', 'active')->paginate(12);
            $category_name = $category->name[\App::getLocale()];

        } else {

            $city_grand = City::find($request->city_id);
            $cities_parents = City::whereParentId($city_grand->id)->pluck('id');
            $all_cities = $cities_parents->merge($city_grand->id);
            $cities_childrens = City::whereIn('parent_id', $cities_parents)->pluck('id');
            $cities = $all_cities->merge($cities_childrens);

            $rows = Product::whereIn('city_id', $cities)->paginate(12);
            $category_name = \Lang::get('data.all');

        }


        $view = view('web.data.data_search', compact('rows'))->render();;
        return response()->json(['html' => $view, 'category_name' => $category_name]);
    }
    public function get_tap_all(Request $request)
    {
        $city_id = \Session::get('tap_city_id');
        $category_id = \Session::get('tap_category_id');
        if ($category_id != null && $city_id !=null) {
            $category = Category::find($category_id); // 15 grand
            $parents = Category::where('parent_id', $category->id)->pluck('id');
            $all_categories = $parents->merge($category->id); // 15 , 16
            $children = Category::whereIn('parent_id', $parents)->pluck('id');
            $chlidren_categories = $all_categories->merge($children);


            $city_grand = City::find($city_id);
            $cities_parents = City::whereParentId($city_grand->id)->pluck('id');
            $all_cities = $cities_parents->merge($city_grand->id);
            $cities_childrens = City::whereIn('parent_id', $cities_parents)->pluck('id');
            $cities = $all_cities->merge($cities_childrens);


            $rows = Product::whereIn('category_id', $chlidren_categories)->whereIn('city_id', $cities)->where('status', 'active')->paginate(12);
            $category_name = $category->name[\App::getLocale()];

        } else {

            $rows = Product::paginate(12);
            $category_name = \Lang::get('data.all');

        }


        $view = view('web.data.data_search', compact('rows'))->render();;
        return response()->json(['html' => $view, 'category_name' => $category_name]);
    }
    public function get_tap_new(Request $request)
    {
        $city_id = \Session::get('tap_city_id');
        $category_id = \Session::get('tap_category_id');
        \Session::flush();
        if ($category_id != null && $city_id !=null) {
            $category = Category::find($category_id); // 15 grand
            $parents = Category::where('parent_id', $category->id)->pluck('id');
            $all_categories = $parents->merge($category->id); // 15 , 16
            $children = Category::whereIn('parent_id', $parents)->pluck('id');
            $chlidren_categories = $all_categories->merge($children);


            $city_grand = City::find($city_id);
            $cities_parents = City::whereParentId($city_grand->id)->pluck('id');
            $all_cities = $cities_parents->merge($city_grand->id);
            $cities_childrens = City::whereIn('parent_id', $cities_parents)->pluck('id');
            $cities = $all_cities->merge($cities_childrens);


            $rows = Product::whereIn('category_id', $chlidren_categories)->whereIn('city_id', $cities)->where('status', 'active')->orderByDesc('id')->paginate(12);
            $category_name = $category->name[\App::getLocale()];

        } else {

            $rows = Product::orderByDESC('id')->paginate(12);
            $category_name = \Lang::get('data.all');

        }


        $view = view('web.data.data_search', compact('rows'))->render();;
        return response()->json(['html' => $view, 'category_name' => $category_name]);
    }

    public function search_new_products(Request $request)
    {


        if ($request->category_id) {
            $category = Category::find($request['category_id']);
            $children = Category::where('parent_id', $category->id)->pluck('id');
            $all_categories = $children->merge($category->id);
            $rows = Product::whereIn('category_id', $all_categories)->where('status', 'active')->orderByDesc('id')->paginate(12);

        } else {
            $rows = Product::where('status', 'active')->orderByDesc('id')->paginate(12);

        }


        $view = view('web.data.data_search', compact('rows'))->render();;
        return response()->json(['html' => $view]);
    }

    public function search_all_products(Request $request)
    {


        if ($request->category_id) {
            $category = Category::find($request['category_id']);
            $children = Category::where('parent_id', $category->id)->pluck('id');
            $all_categories = $children->merge($category->id);
            $rows = Product::whereIn('category_id', $all_categories)->where('status', 'active')->paginate(12);

        } else {
            $rows = Product::where('status', 'active')->paginate(12);

        }


        $view = view('web.data.data_search', compact('rows'))->render();;
        return response()->json(['html' => $view]);
    }

    public function black_list()
    {
        return view('web.data.black_list');
    }


    public function search_black_list(Request $request)
    {
        $rows = Block::where("mobile", $request['mobile'])->orWhere('id', $request['mobile'])->get();
        $data = [];
        foreach ($rows as $row) {
            $arr['name'] = $row->user->username ? $row->user->username : $row->user->mobile;
            $data[] = $arr;
        }

        if (count($rows) > 0) {
            $view = view('web.data.black_list_foreach', compact('rows'))->render();
            return response()->json(['value' => true, 'data' => $data, 'view' => $view, 'status' => 1]);
        } else {
            $view = view('web.data.empty_black_list')->render();
            return response()->json(['value' => true, 'data' => $data, 'view' => $view, 'status' => 0]);
        }

    }

    public function search_location_ajax(Request $request)
    {
        $lat = $request['lat'];
        $lng = $request['lng'];
        $max_distance = 30;
        $lat_small = $lat - ($max_distance * 0.018);
        $lat_large = $lat + ($max_distance * 0.018);
        $lng_small = $lng - ($max_distance * 0.018);
        $lng_large = $lng + ($max_distance * 0.018);

        if ($request->category_id) {

            $category = Category::find($request['category_id']);
            $children = Category::where('parent_id', $category->id)->pluck('id');
            $all_categories = $children->merge($category);
            $rows = Product::where('category_id', $request['category_id'])->where('status', 'active')->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->paginate(12);

        } else {
            $rows = Product::where('title', 'like', "%$request->search%")->where('status', 'active')->whereBetween('lat', [$lat_small, $lat_large])->whereBetween('lng', [$lng_small, $lng_large])->paginate(12);

        }


        $view = view('web.data.data_search', compact('rows'))->render();
        return response()->json(['html' => $view]);
//        return response()->json(['data' => $rows]);
    }

    public function duplicate_service_charges()
    {
        return view('web.data.duplicate_service_charges');
    }

    public function terms()
    {
        return view('web.data.terms');
    }

    public function rating_system()
    {
        return view('web.data.rating_system');
    }

    public function not_allowed()
    {
        return view('web.data.not_allowed');
    }

    public function membership()
    {
        return view('web.data.membership');
    }
}
