<?php

namespace App\Http\Resources;

use App\Models\Category;
use App\Models\Favourite;
use Carbon\Carbon;
use Illuminate\Http\Resources\Json\JsonResource;

class ProductsResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {

        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $category = Category::find($this->category_id);
        $parent_category = Category::find($category->parent_id);

        if ($parent_category){
            $categories = Category::whereParentId($parent_category->id)->get();
        }else{
            $categories = Category::whereParentId($category->id)->get();
        }
        return [
            'id' => $this->id,
            'title' => $this->title,
            'category_id' => (integer)$this->category_id,
            'category_name' => $this->category->name[$lang],
            'category_car_option' => $this->category->car_option,
            'city_id' => (integer)$this->city_id,
            'city_name' => $this->city->name[$lang],
            'mobile' => $this->mobile,
            'hide_mobile' => $this->hide_mobile,
            'ad_type' => $this->ad_type ? $this->ad_type : '',
            'year' => $this->year ? $this->year : '',
            'car_status' => $this->car_status ? $this->car_status : '',
            'installment_destination' => $this->installment_destination ? $this->installment_destination : '',
            'fetis' => $this->fetis ? $this->fetis : '',
            'fuel' => $this->fuel ? $this->fuel : '',
            'double' => $this->double ? $this->double : '',
            'km' => $this->km ? $this->km : '',
            'price' => $this->price,
            'detail' => $this->detail,
            'lat' => $this->lat ? $this->lat : '',
            'lng' => $this->lng ? $this->lng : '',
            'code' => $this->code ? $this->code : '',
            'views' => $this->views ? (integer)$this->views : 0,
            'status' => $this->status,
            'user_id' => (integer)$this->user_id,
            'user_name' => $this->user->name ? $this->user->name : "",
            'ago' => Carbon::parse($this->created_at)->diffForHumans(),
            'image' => ProductImagesResource::collection($this->images),
            'is_favorite' => $this->is_favorite ? $this->is_favorite : false,
            'comments' => CommentsResource::collection($this->comments),
            'words_search' => (count($categories) >0) ?  CategoriesResource::collection($categories) : [],
        ];
    }
}
