<?php

namespace App\Http\Resources;

use App\Models\Message;
use Carbon\Carbon;
use Illuminate\Http\Resources\Json\JsonResource;
use JWTAuth;
use Tymon\JWTAuth\Exceptions\JWTException;

class RoomResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $auth = $request->header('Authorization');
        if ($auth) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
            }
        }
        $messages = Message::where('room_id', $this->id)->get();
        return [
            'id' => $this->id,
            'user_id' => $this->sender_id != $user->id ? $this->sender_id : $this->receiver_id,
            'user_name' => $this->sender_id != $user->id ? $this->sender->name : $this->receiver->name,
            'user_image' => $this->sender_id != $user->id ? $this->sender->image ? asset('images/users/') . $this->sender->image : '' : $this->receiver->image ? asset('images/users/') . $this->receiver->image : '',
            'body' => $this->messages()->latest()->value('body') ? $this->messages()->latest()->value('body') : '',
            'ago' => Carbon::parse($this->messages()->latest()->value('created_at'))->diffForHumans(),
            'messages' => MessagesResource::collection($messages)
        ];
    }
}
